package
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Mar 4, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Dotenv
Small .env file loader.
Usage
err := dotenv.LoadFile(dotenv.Options{})
All options
err := dotenv.LoadFile(dotenv.Options{
FilePath: ".env",
Overwrite: false,
})
# A comment
KEY1=value 1
KEY2=value 2
Documentation
¶
Load .env file.
Usage:
err := dotenv.LoadFile(dotenv.Options{})
All options:
err := dotenv.LoadFile(dotenv.Options{
FilePath: ".env",
Overwrite: false,
})
File format:
# A comment
KEY1=value 1
KEY2=value 2
type Options struct {
FilePath string
Overwrite bool
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.